==> openshift-model-machine-6.7.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineHealthCheckSpecBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineHealthCheckSpecBuilder extends MachineHealthCheckSpecFluentImpl<MachineHealthCheckSpecBuilder> implements VisitableBuilder<MachineHealthCheckSpec,MachineHealthCheckSpecBuilder>{
  public MachineHealthCheckSpecBuilder() {
    this(false);
  }
  public MachineHealthCheckSpecBuilder(Boolean validationEnabled) {
    this(new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,MachineHealthCheckSpec instance) {
    this(fluent, instance, false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,MachineHealthCheckSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withMaxUnhealthy(instance.getMaxUnhealthy());
      fluent.withNodeStartupTimeout(instance.getNodeStartupTimeout());
      fluent.withRemediationTemplate(instance.getRemediationTemplate());
      fluent.withSelector(instance.getSelector());
      fluent.withUnhealthyConditions(instance.getUnhealthyConditions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpec instance) {
    this(instance,false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withMaxUnhealthy(instance.getMaxUnhealthy());
      this.withNodeStartupTimeout(instance.getNodeStartupTimeout());
      this.withRemediationTemplate(instance.getRemediationTemplate());
      this.withSelector(instance.getSelector());
      this.withUnhealthyConditions(instance.getUnhealthyConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachineHealthCheckSpecFluent<?> fluent;
  Boolean validationEnabled;
  public MachineHealthCheckSpec build() {
    MachineHealthCheckSpec buildable = new MachineHealthCheckSpec(fluent.getMaxUnhealthy(),fluent.getNodeStartupTimeout(),fluent.getRemediationTemplate(),fluent.getSelector(),fluent.getUnhealthyConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-machine-6.8.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineHealthCheckSpecBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineHealthCheckSpecBuilder extends MachineHealthCheckSpecFluent<MachineHealthCheckSpecBuilder> implements VisitableBuilder<MachineHealthCheckSpec,MachineHealthCheckSpecBuilder>{
  public MachineHealthCheckSpecBuilder() {
    this(false);
  }
  public MachineHealthCheckSpecBuilder(Boolean validationEnabled) {
    this(new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,MachineHealthCheckSpec instance) {
    this(fluent, instance, false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,MachineHealthCheckSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MachineHealthCheckSpec());

    if (instance != null) {
      fluent.withMaxUnhealthy(instance.getMaxUnhealthy());
      fluent.withNodeStartupTimeout(instance.getNodeStartupTimeout());
      fluent.withRemediationTemplate(instance.getRemediationTemplate());
      fluent.withSelector(instance.getSelector());
      fluent.withUnhealthyConditions(instance.getUnhealthyConditions());
      fluent.withMaxUnhealthy(instance.getMaxUnhealthy());
      fluent.withNodeStartupTimeout(instance.getNodeStartupTimeout());
      fluent.withRemediationTemplate(instance.getRemediationTemplate());
      fluent.withSelector(instance.getSelector());
      fluent.withUnhealthyConditions(instance.getUnhealthyConditions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpec instance) {
    this(instance,false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MachineHealthCheckSpec());

    if (instance != null) {
      this.withMaxUnhealthy(instance.getMaxUnhealthy());
      this.withNodeStartupTimeout(instance.getNodeStartupTimeout());
      this.withRemediationTemplate(instance.getRemediationTemplate());
      this.withSelector(instance.getSelector());
      this.withUnhealthyConditions(instance.getUnhealthyConditions());
      this.withMaxUnhealthy(instance.getMaxUnhealthy());
      this.withNodeStartupTimeout(instance.getNodeStartupTimeout());
      this.withRemediationTemplate(instance.getRemediationTemplate());
      this.withSelector(instance.getSelector());
      this.withUnhealthyConditions(instance.getUnhealthyConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachineHealthCheckSpecFluent<?> fluent;
  Boolean validationEnabled;
  public MachineHealthCheckSpec build() {
    MachineHealthCheckSpec buildable = new MachineHealthCheckSpec(fluent.buildMaxUnhealthy(),fluent.getNodeStartupTimeout(),fluent.buildRemediationTemplate(),fluent.buildSelector(),fluent.buildUnhealthyConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
